@@ -28,6 +28,7 @@ from ..utils import (
     GeoLocation,
     HttpCredentials,
     Proxy,
+    RecordHar,
     RecordVideo,
     SelectionType,
     SupportedBrowsers,
@@ -367,6 +368,7 @@ class PlaywrightState(LibraryComponent):
         defaultBrowserType: Optional[SupportedBrowsers] = None,
         hideRfBrowser: bool = False,
         recordVideo: Optional[RecordVideo] = None,
+        recordHar: Optional[RecordHar] = None,
     ) -> str:
         """Create a new BrowserContext with specified options.
         See `Browser, Context and Page` for more information about BrowserContext.
@@ -423,7 +425,8 @@ class PlaywrightState(LibraryComponent):
 
         ``offline`` Whether to emulate network being offline. Defaults to False.
 
-        ``httpCredentials`` Credentials for HTTP authentication.
+        ``httpCredentials`` Credentials for
+        [https://developer.mozilla.org/en-US/docs/Web/HTTP/Authentication|HTTP authentication].
         - example: ``{'username': 'admin', 'password': '123456'}``
         - ``username``
         - ``password``
@@ -466,6 +469,16 @@ class PlaywrightState(LibraryComponent):
         `size` is dictionary containing `width` (Video frame width) and  `height`
         (Video frame height) keys.
 
+        ``recordHar`` Enables [http://www.softwareishard.com/blog/har-12-spec/|HAR] recording
+        for all pages into to a file. Must be path to file, example ${OUTPUT_DIR}/har.file.
+        If not specified, the HAR is not recorded. Make sure to await context to close for the
+        to be saved.
+
+        `omitContent`: Optional setting to control whether to omit request content
+        from the HAR. Default is False `path`: Path on the filesystem to write the HAR file to.
+
+        The ${OUTPUTDIR}/browser/ is removed at the first suite startup.
+
         Example:
         | Test an iPhone
         |     ${device}=    `Get Device`    iPhone X
